WireMixinWithWireData mixin
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get<
T> (String dataKey) → Future< T> -
getMany(
List< String> many) → Future<Map< String, dynamic> > -
has(
String dataKey) → bool -
hasNot(
String dataKey) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String dataKey) → Future< void> -
reset(
String dataKey) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update<
T> (String dataKey, {T? data, bool refresh = true}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited